@@ -1,7 +1,9 @@
+from lxml import etree
 
 import logging
 
-from suds.client import Client
+from zeep import Client
+
 from six import itervalues
 from .currencies import GPAY_CURRENCIES
 
@@ -18,6 +20,10 @@ GPAY_PAYMENT_PAGE_TEST_URL = "https://sandbox.gestpay.net/pagam/pagam.aspx?a={sh
 
 GPAY_DEFAULT_CURRENCY = GPAY_CURRENCIES['EUR']['UICCode']
 
+class GestpayException(Exception):
+    pass
+
+
 class GestPAY(object):
     def __init__(self, shop_login, test=False, debug=False):
         self.debug = debug
@@ -94,6 +100,8 @@ class GestPAY(object):
         if data['TransactionResult'] == "OK":
             crypted_string = data['CryptDecryptString']
             return self._generate_payment_page_url(crypted_string)
+        else:
+            raise GestpayException(data)
         
         return url
 
@@ -280,7 +288,7 @@ class GestPAY(object):
     def make_request(self, client, key, method, data):
         try:
             response_data = getattr(client.service, method)(**data)
-            response = response_data[key]
+            response = elem2dict(response_data)
         except Exception as e: 
             response = {"TransactionResult": "KO",
                  "TransactionType": "",
@@ -292,3 +300,31 @@ class GestPAY(object):
             _log.info(response)
 
         return response
+
+
+def elem2dict(node):
+    """
+    Convert an lxml.etree node tree into a dict.
+    """
+    result = {}
+
+    for element in node.iterchildren():
+        # Remove namespace prefix
+        key = element.tag.split('}')[1] if '}' in element.tag else element.tag
+
+        # Process element as tree element if the inner XML contains non-whitespace content
+        if element.text and element.text.strip():
+            value = element.text
+        else:
+            value = elem2dict(element)
+        if key in result:
+
+            
+            if type(result[key]) is list:
+                result[key].append(value)
+            else:
+                tempvalue = result[key].copy()
+                result[key] = [tempvalue, value]
+        else:
+            result[key] = value
+    return result
